Local help
===========

* `Using Thonny debuggers <stepping.rst>`_
* `General advice on debugging <debugging.rst>`_
* `Using 3rd party packages <packages.rst>`_
* `Simple mode and expert mode <modes.rst>`_


Online
======
There is more information available on Thonny wiki: https://bitbucket.org/plas/thonny/wiki/Home.
